@@ -1,27 +1,17 @@
 import traceback
-
 from itertools import product
-from socket import (
-    error as socket_error,
-    timeout as timeout_error,
-)
+from socket import error as socket_error, timeout as timeout_error
 
 import click
 import gevent
-
 from paramiko import SSHException
 
 import pyinfra
-
 from pyinfra import logger
 from pyinfra.progress import progress_spinner
 
 from .arguments import get_executor_kwarg_keys
-from .command import (
-    FunctionCommand,
-    PyinfraCommand,
-    StringCommand,
-)
+from .command import FunctionCommand, PyinfraCommand, StringCommand
 from .exceptions import PyinfraError
 from .util import (
     format_exception,
@@ -34,10 +24,17 @@ from .util import (
 
 @memoize
 def show_pre_or_post_condition_warning(condition_name):
-    logger.warning('The `{0}` argument is in beta!'.format(condition_name))
+    logger.warning("The `{0}` argument is in beta!".format(condition_name))
 
 
-def _run_shell_command(state, host, command, global_kwargs, executor_kwargs):
+def _run_shell_command(
+    state,
+    host,
+    command,
+    global_kwargs,
+    executor_kwargs,
+    return_combined_output=False,
+):
     status = False
     combined_output_lines = []
 
@@ -47,59 +44,74 @@ def _run_shell_command(state, host, command, global_kwargs, executor_kwargs):
         log_host_command_error(
             host,
             e,
-            timeout=global_kwargs['timeout'],
+            timeout=global_kwargs["timeout"],
         )
 
     # If we failed and have no already printed the stderr, print it
     if status is False and not state.print_output:
         print_host_combined_output(host, combined_output_lines)
 
+    if return_combined_output:
+        return status, combined_output_lines
     return status
 
 
-def _run_server_op(state, host, op_hash):
-    state.trigger_callbacks('operation_host_start', host, op_hash)
+def run_host_op(state, host, op_hash):
+    state.trigger_callbacks("operation_host_start", host, op_hash)
 
     if op_hash not in state.ops[host]:
-        logger.info('{0}{1}'.format(host.print_prefix, click.style('Skipped', 'blue')))
+        logger.info("{0}{1}".format(host.print_prefix, click.style("Skipped", "blue")))
         return True
 
     op_data = state.get_op_data(host, op_hash)
-    global_kwargs = op_data['global_kwargs']
+    global_kwargs = op_data["global_kwargs"]
 
     op_meta = state.get_op_meta(op_hash)
 
-    ignore_errors = global_kwargs['ignore_errors']
+    ignore_errors = global_kwargs["ignore_errors"]
 
-    logger.debug('Starting operation {0} on {1}'.format(
-        ', '.join(op_meta['names']), host,
-    ))
+    logger.debug(
+        "Starting operation {0} on {1}".format(
+            ", ".join(op_meta["names"]),
+            host,
+        ),
+    )
 
     executor_kwarg_keys = get_executor_kwarg_keys()
     base_executor_kwargs = {
-        key: global_kwargs[key]
-        for key in executor_kwarg_keys
-        if key in global_kwargs
+        key: global_kwargs[key] for key in executor_kwarg_keys if key in global_kwargs
     }
 
-    precondition = global_kwargs['precondition']
+    precondition = global_kwargs["precondition"]
     if precondition:
-        show_pre_or_post_condition_warning('precondition')
+        show_pre_or_post_condition_warning("precondition")
     if precondition and not _run_shell_command(
-        state, host, StringCommand(precondition), global_kwargs, base_executor_kwargs,
+        state,
+        host,
+        StringCommand(precondition),
+        global_kwargs,
+        base_executor_kwargs,
     ):
         log_error_or_warning(
-            host, ignore_errors,
-            description='precondition failed: {0}'.format(precondition),
+            host,
+            ignore_errors,
+            description="precondition failed: {0}".format(precondition),
         )
         if not ignore_errors:
-            state.trigger_callbacks('operation_host_error', host, op_hash)
+            state.trigger_callbacks("operation_host_error", host, op_hash)
             return False
 
     state.ops_run.add(op_hash)
 
-    # ...loop through each command
-    for i, command in enumerate(op_data['commands']):
+    if host.executing_op_hash is None:
+        host.executing_op_hash = op_hash
+    else:
+        host.nested_executing_op_hash = op_hash
+
+    return_status = False
+    all_combined_output_lines = []
+
+    for i, command in enumerate(op_data["commands"]):
 
         status = False
 
@@ -110,25 +122,35 @@ def _run_server_op(state, host, op_hash):
         #
 
         if not isinstance(command, PyinfraCommand):
-            raise TypeError('{0} is an invalid pyinfra command!'.format(command))
+            raise TypeError("{0} is an invalid pyinfra command!".format(command))
 
         if isinstance(command, FunctionCommand):
             try:
                 status = command.execute(state, host, executor_kwargs)
             except Exception as e:  # Custom functions could do anything, so expect anything!
                 logger.warning(traceback.format_exc())
-                logger.error('{0}{1}'.format(
-                    host.print_prefix,
-                    click.style(
-                        'Unexpected error in Python callback: {0}'.format(
-                            format_exception(e),
+                logger.error(
+                    "{0}{1}".format(
+                        host.print_prefix,
+                        click.style(
+                            "Unexpected error in Python callback: {0}".format(
+                                format_exception(e),
+                            ),
+                            "red",
                         ),
-                        'red',
                     ),
-                ))
+                )
 
         elif isinstance(command, StringCommand):
-            status = _run_shell_command(state, host, command, global_kwargs, executor_kwargs)
+            status, combined_output_lines = _run_shell_command(
+                state,
+                host,
+                command,
+                global_kwargs,
+                executor_kwargs,
+                return_combined_output=True,
+            )
+            all_combined_output_lines.extend(combined_output_lines)
 
         else:
             try:
@@ -137,127 +159,154 @@ def _run_server_op(state, host, op_hash):
                 log_host_command_error(
                     host,
                     e,
-                    timeout=global_kwargs['timeout'],
+                    timeout=global_kwargs["timeout"],
                 )
 
         # Break the loop to trigger a failure
         if status is False:
             break
 
-        state.results[host]['commands'] += 1
+        state.results[host]["commands"] += 1
 
     # Commands didn't break, so count our successes & return True!
     else:
-        postcondition = global_kwargs['postcondition']
+        postcondition = global_kwargs["postcondition"]
         if postcondition:
-            show_pre_or_post_condition_warning('postcondition')
+            show_pre_or_post_condition_warning("postcondition")
         if postcondition and not _run_shell_command(
-            state, host, StringCommand(postcondition), global_kwargs, base_executor_kwargs,
+            state,
+            host,
+            StringCommand(postcondition),
+            global_kwargs,
+            base_executor_kwargs,
         ):
             log_error_or_warning(
-                host, ignore_errors,
-                description='postcondition failed: {0}'.format(postcondition),
+                host,
+                ignore_errors,
+                description="postcondition failed: {0}".format(postcondition),
             )
             if not ignore_errors:
-                state.trigger_callbacks('operation_host_error', host, op_hash)
+                state.trigger_callbacks("operation_host_error", host, op_hash)
                 return False
 
         # Count success
-        state.results[host]['ops'] += 1
-        state.results[host]['success_ops'] += 1
+        state.results[host]["ops"] += 1
+        state.results[host]["success_ops"] += 1
 
-        logger.info('{0}{1}'.format(
-            host.print_prefix,
-            click.style(
-                'Success' if len(op_data['commands']) > 0 else 'No changes',
-                'green',
+        logger.info(
+            "{0}{1}".format(
+                host.print_prefix,
+                click.style(
+                    "Success" if len(op_data["commands"]) > 0 else "No changes",
+                    "green",
+                ),
             ),
-        ))
+        )
 
         # Trigger any success handler
-        if global_kwargs['on_success']:
-            global_kwargs['on_success'](state, host, op_hash)
+        if global_kwargs["on_success"]:
+            global_kwargs["on_success"](state, host, op_hash)
 
-        state.trigger_callbacks('operation_host_success', host, op_hash)
-        return True
+        state.trigger_callbacks("operation_host_success", host, op_hash)
+        return_status = True
 
-    # Up error_ops & log
-    state.results[host]['error_ops'] += 1
+    if return_status is False:
+        # Up error_ops & log
+        state.results[host]["error_ops"] += 1
 
-    log_error_or_warning(host, ignore_errors)
+        log_error_or_warning(host, ignore_errors)
 
-    # Always trigger any error handler
-    if global_kwargs['on_error']:
-        global_kwargs['on_error'](state, host, op_hash)
+        # Always trigger any error handler
+        if global_kwargs["on_error"]:
+            global_kwargs["on_error"](state, host, op_hash)
 
-    # Ignored, op "completes" w/ ignored error
-    if ignore_errors:
-        state.results[host]['ops'] += 1
+        # Ignored, op "completes" w/ ignored error
+        if ignore_errors:
+            state.results[host]["ops"] += 1
 
-    # Unignored error -> False
-    state.trigger_callbacks('operation_host_error', host, op_hash)
-    if ignore_errors:
-        return True
-    return False
+        # Unignored error -> False
+        state.trigger_callbacks("operation_host_error", host, op_hash)
+
+        if ignore_errors:
+            return_status = True
+
+    op_data["operation_meta"].set_combined_output_lines(all_combined_output_lines)
+
+    if host.nested_executing_op_hash:
+        host.nested_executing_op_hash = None
+    else:
+        host.executing_op_hash = None
+
+    return return_status
 
 
-def _log_operation_start(op_meta):
-    op_types = []
-    if op_meta['serial']:
-        op_types.append('serial')
-    if op_meta['run_once']:
-        op_types.append('run once')
+def log_operation_start(op_meta, op_types=None, prefix="--> "):
+    op_types = op_types or []
+    if op_meta["serial"]:
+        op_types.append("serial")
+    if op_meta["run_once"]:
+        op_types.append("run once")
 
-    args = ''
-    if op_meta['args']:
-        args = '({0})'.format(', '.join(str(arg) for arg in op_meta['args']))
+    args = ""
+    if op_meta["args"]:
+        args = "({0})".format(", ".join(str(arg) for arg in op_meta["args"]))
 
-    logger.info('{0} {1} {2}'.format(
-        click.style('--> Starting{0}operation:'.format(
-            ' {0} '.format(', '.join(op_types)) if op_types else ' ',
-        ), 'blue'),
-        click.style(', '.join(op_meta['names']), bold=True),
-        args,
-    ))
+    logger.info(
+        "{0} {1} {2}".format(
+            click.style(
+                "{0}Starting{1}operation:".format(
+                    prefix,
+                    " {0} ".format(", ".join(op_types)) if op_types else " ",
+                ),
+                "blue",
+            ),
+            click.style(", ".join(op_meta["names"]), bold=True),
+            args,
+        ),
+    )
 
 
-def _run_server_ops(state, host, progress=None):
-    '''
+def _run_host_ops(state, host, progress=None):
+    """
     Run all ops for a single server.
-    '''
+    """
 
-    logger.debug('Running all ops on {0}'.format(host))
+    logger.debug("Running all ops on {0}".format(host))
 
     for op_hash in state.get_op_order():
         op_meta = state.get_op_meta(op_hash)
-        _log_operation_start(op_meta)
+        log_operation_start(op_meta)
 
-        result = _run_server_op(state, host, op_hash)
+        result = run_host_op(state, host, op_hash)
 
         # Trigger CLI progress if provided
         if progress:
             progress((host, op_hash))
 
         if result is False:
-            raise PyinfraError('Error in operation {0} on {1}'.format(
-                ', '.join(op_meta['names']), host,
-            ))
+            raise PyinfraError(
+                "Error in operation {0} on {1}".format(
+                    ", ".join(op_meta["names"]),
+                    host,
+                ),
+            )
 
         if pyinfra.is_cli:
             click.echo(err=True)
 
 
 def _run_serial_ops(state):
-    '''
+    """
     Run all ops for all servers, one server at a time.
-    '''
+    """
 
     for host in list(state.inventory.iter_active_hosts()):
         host_operations = product([host], state.get_op_order())
         with progress_spinner(host_operations) as progress:
             try:
-                _run_server_ops(
-                    state, host,
+                _run_host_ops(
+                    state,
+                    host,
                     progress=progress,
                 )
             except PyinfraError:
@@ -265,16 +314,18 @@ def _run_serial_ops(state):
 
 
 def _run_no_wait_ops(state):
-    '''
+    """
     Run all ops for all servers at once.
-    '''
+    """
 
     hosts_operations = product(state.inventory.iter_active_hosts(), state.get_op_order())
     with progress_spinner(hosts_operations) as progress:
         # Spawn greenlet for each host to run *all* ops
         greenlets = [
             state.pool.spawn(
-                _run_server_ops, state, host,
+                _run_host_ops,
+                state,
+                host,
                 progress=progress,
             )
             for host in state.inventory.iter_active_hosts()
@@ -283,22 +334,22 @@ def _run_no_wait_ops(state):
 
 
 def _run_single_op(state, op_hash):
-    '''
+    """
     Run a single operation for all servers. Can be configured to run in serial.
-    '''
+    """
 
-    state.trigger_callbacks('operation_start', op_hash)
+    state.trigger_callbacks("operation_start", op_hash)
 
     op_meta = state.get_op_meta(op_hash)
-    _log_operation_start(op_meta)
+    log_operation_start(op_meta)
 
     failed_hosts = set()
 
-    if op_meta['serial']:
+    if op_meta["serial"]:
         with progress_spinner(state.inventory.iter_active_hosts()) as progress:
             # For each host, run the op
             for host in state.inventory.iter_active_hosts():
-                result = _run_server_op(state, host, op_hash)
+                result = run_host_op(state, host, op_hash)
                 progress(host)
 
                 if not result:
@@ -309,21 +360,17 @@ def _run_single_op(state, op_hash):
         batches = [list(state.inventory.iter_active_hosts())]
 
         # If parallel set break up the inventory into a series of batches
-        if op_meta['parallel']:
-            parallel = op_meta['parallel']
+        if op_meta["parallel"]:
+            parallel = op_meta["parallel"]
             hosts = list(state.inventory.iter_active_hosts())
 
-            batches = [
-                hosts[i:i + parallel]
-                for i in range(0, len(hosts), parallel)
-            ]
+            batches = [hosts[i : i + parallel] for i in range(0, len(hosts), parallel)]
 
         for batch in batches:
             with progress_spinner(batch) as progress:
                 # Spawn greenlet for each host
                 greenlet_to_host = {
-                    state.pool.spawn(_run_server_op, state, host, op_hash): host
-                    for host in batch
+                    state.pool.spawn(run_host_op, state, host, op_hash): host for host in batch
                 }
 
                 # Trigger CLI progress as hosts complete if provided
@@ -342,18 +389,18 @@ def _run_single_op(state, op_hash):
     if pyinfra.is_cli:
         click.echo(err=True)
 
-    state.trigger_callbacks('operation_end', op_hash)
+    state.trigger_callbacks("operation_end", op_hash)
 
 
 def run_ops(state, serial=False, no_wait=False):
-    '''
+    """
     Runs all operations across all servers in a configurable manner.
 
     Args:
         state (``pyinfra.api.State`` obj): the deploy state to execute
         serial (boolean): whether to run operations host by host
         no_wait (boolean): whether to wait for all hosts between operations
-    '''
+    """
 
     # Flag state as deploy in process
     state.is_executing = True
