@@ -5,20 +5,20 @@ from pyinfra.api import FactBase
 
 from .util.packaging import parse_packages
 
-BREW_REGEX = r'^([^\s]+)\s([0-9\._+a-z\-]+)'
+BREW_REGEX = r"^([^\s]+)\s([0-9\._+a-z\-]+)"
 
 
 def new_cask_cli(version):
-    '''
-        Returns true if brew is version 2.6.0 or later and thus has the new CLI for casks.
-        i.e. we need to use brew list --cask instead of brew cask list
-        See https://brew.sh/2020/12/01/homebrew-2.6.0/
-        The version string returned by BrewVersion is a list of major, minor, patch version numbers
-    '''
+    """
+    Returns true if brew is version 2.6.0 or later and thus has the new CLI for casks.
+    i.e. we need to use brew list --cask instead of brew cask list
+    See https://brew.sh/2020/12/01/homebrew-2.6.0/
+    The version string returned by BrewVersion is a list of major, minor, patch version numbers
+    """
     return (version[0] >= 3) or ((version[0] >= 2) and version[1] >= 6)
 
 
-VERSION_MATCHER = re.compile(r'^Homebrew\s+(?P<major>\d+)\.(?P<minor>\d+)\.(?P<patch>\d+).*$')
+VERSION_MATCHER = re.compile(r"^Homebrew\s+(?P<major>\d+)\.(?P<minor>\d+)\.(?P<patch>\d+).*$")
 
 
 def unknown_version():
@@ -26,16 +26,17 @@ def unknown_version():
 
 
 class BrewVersion(FactBase):
-    '''
+    """
     Returns the version of brew installed as a semantic versioning tuple:
 
     .. code:: python
 
         [major, minor, patch]
 
-    '''
-    command = 'brew --version'
-    requires_command = 'brew'
+    """
+
+    command = "brew --version"
+    requires_command = "brew"
 
     @staticmethod
     def default():
@@ -44,14 +45,14 @@ class BrewVersion(FactBase):
     def process(self, output):
         m = VERSION_MATCHER.match(output[0])
         if m is not None:
-            return [int(m.group(key)) for key in ['major', 'minor', 'patch']]
+            return [int(m.group(key)) for key in ["major", "minor", "patch"]]
         else:
-            logger.warning('could not parse version string from brew: %s', output[0])
+            logger.warning("could not parse version string from brew: %s", output[0])
             return self.default()
 
 
 class BrewPackages(FactBase):
-    '''
+    """
     Returns a dict of installed brew packages:
 
     .. code:: python
@@ -59,10 +60,10 @@ class BrewPackages(FactBase):
         {
             "package_name": ["version"],
         }
-    '''
+    """
 
-    command = 'brew list --versions'
-    requires_command = 'brew'
+    command = "brew list --versions"
+    requires_command = "brew"
 
     default = dict
 
@@ -71,7 +72,7 @@ class BrewPackages(FactBase):
 
 
 class BrewCasks(BrewPackages):
-    '''
+    """
     Returns a dict of installed brew casks:
 
     .. code:: python
@@ -79,20 +80,22 @@ class BrewCasks(BrewPackages):
         {
             "package_name": ["version"],
         }
-    '''
+    """
 
-    command = (r'if brew --version | grep -q -e "Homebrew\ +(1\.|2\.[0-5]).*" 1>/dev/null;'
-               r'then brew cask list --versions; else brew list --cask --versions; fi')
-    requires_command = 'brew'
+    command = (
+        r'if brew --version | grep -q -e "Homebrew\ +(1\.|2\.[0-5]).*" 1>/dev/null;'
+        r"then brew cask list --versions; else brew list --cask --versions; fi"
+    )
+    requires_command = "brew"
 
 
 class BrewTaps(FactBase):
-    '''
+    """
     Returns a list of brew taps.
-    '''
+    """
 
-    command = 'brew tap'
-    requires_command = 'brew'
+    command = "brew tap"
+    requires_command = "brew"
 
     default = list
 
