@@ -2,11 +2,11 @@ from pyinfra.api import FactBase
 
 from .util.packaging import parse_packages
 
-CHOCO_REGEX = r'^([a-zA-Z0-9\.\-\+\_]+)\s([0-9\.]+)$'
+CHOCO_REGEX = r"^([a-zA-Z0-9\.\-\+\_]+)\s([0-9\.]+)$"
 
 
 class ChocoPackages(FactBase):
-    '''
+    """
     Returns a dict of installed choco (Chocolatey) packages:
 
     .. code:: python
@@ -14,10 +14,10 @@ class ChocoPackages(FactBase):
         {
             "package_name": ["version"],
         }
-    '''
+    """
 
-    command = 'choco list --local-only'
-    shell_executable = 'ps'
+    command = "choco list --local-only"
+    shell_executable = "ps"
 
     default = dict
 
@@ -26,12 +26,12 @@ class ChocoPackages(FactBase):
 
 
 class ChocoVersion(FactBase):
-    '''
+    """
     Returns the choco (Chocolatey) version.
-    '''
+    """
 
-    command = 'choco --version'
+    command = "choco --version"
 
     @staticmethod
     def process(output):
-        return ''.join(output).replace('\n', '')
+        return "".join(output).replace("\n", "")
