@@ -5,7 +5,7 @@ from .util.packaging import parse_zypper_repositories
 
 
 class ZypperRepositories(FactBase):
-    '''
+    """
     Returns a list of installed zypper repositories:
 
     .. code:: python
@@ -19,12 +19,12 @@ class ZypperRepositories(FactBase):
                 "type": "rpm-md",
             },
         ]
-    '''
+    """
 
     command = make_cat_files_command(
-        '/etc/zypp/repos.d/*.repo',
+        "/etc/zypp/repos.d/*.repo",
     )
-    requires_command = 'zypper'
+    requires_command = "zypper"
 
     default = list
 
