@@ -1,6 +1,6 @@
-'''
+"""
 Manage OpenRC init services.
-'''
+"""
 
 from pyinfra import host
 from pyinfra.api import operation
@@ -12,11 +12,14 @@ from .util.service import handle_service_control
 @operation
 def service(
     service,
-    running=True, restarted=False, reloaded=False,
-    command=None, enabled=None,
-    runlevel='default',
+    running=True,
+    restarted=False,
+    reloaded=False,
+    command=None,
+    enabled=None,
+    runlevel="default",
 ):
-    '''
+    """
     Manage the state of OpenRC services.
 
     + service: name of the service to manage
@@ -26,14 +29,17 @@ def service(
     + command: custom command to pass like: ``rc-service <service> <command>``
     + enabled: whether this service should be enabled/disabled on boot
     + runlevel: runlevel to manage services for
-    '''
+    """
 
     yield from handle_service_control(
         host,
         service,
         host.get_fact(OpenrcStatus, runlevel=runlevel),
-        'rc-service {0} {1}',
-        running, restarted, reloaded, command,
+        "rc-service {0} {1}",
+        running,
+        restarted,
+        reloaded,
+        command,
     )
 
     if isinstance(enabled, bool):
@@ -41,9 +47,9 @@ def service(
         is_enabled = openrc_enabled.get(service, False)
 
         if enabled and not is_enabled:
-            yield 'rc-update add {0}'.format(service)
+            yield "rc-update add {0}".format(service)
             openrc_enabled[service] = True
 
         if not enabled and is_enabled:
-            yield 'rc-update del {0}'.format(service)
+            yield "rc-update del {0}".format(service)
             openrc_enabled[service] = False
