@@ -1,13 +1,17 @@
-'''
+"""
 The Python module allows you to execute Python code within the context of a deploy.
-'''
+"""
 
+from inspect import getfullargspec
+
+from pyinfra import logger
 from pyinfra.api import FunctionCommand, operation
+from pyinfra.api.util import get_call_location
 
 
 @operation(is_idempotent=False)
 def call(function, *args, **kwargs):
-    '''
+    """
     Execute a Python function within a deploy.
 
     + function: the function to execute
@@ -38,10 +42,17 @@ def call(function, *args, **kwargs):
             hello="world",
         )
 
-    '''
+    """
 
-    kwargs.pop('state', None)
-    kwargs.pop('host', None)
+    argspec = getfullargspec(function)
+    if "state" in argspec.args and "host" in argspec.args:
+        logger.warning(
+            "Callback functions used in `python.call` operations no "
+            f"longer take `state` and `host` arguments: {get_call_location(frame_offset=3)}",
+        )
+
+    kwargs.pop("state", None)
+    kwargs.pop("host", None)
     yield FunctionCommand(function, args, kwargs)
 
 
@@ -50,6 +61,6 @@ def raise_exception(exception, *args, **kwargs):
     def raise_exc(*args, **kwargs):  # pragma: no cover
         raise exception(*args, **kwargs)
 
-    kwargs.pop('state', None)
-    kwargs.pop('host', None)
+    kwargs.pop("state", None)
+    kwargs.pop("host", None)
     yield FunctionCommand(raise_exc, args, kwargs)
