@@ -1,23 +1,23 @@
-'''
+"""
 Manage systemd services.
-'''
+"""
 
 from pyinfra import host
 from pyinfra.api import operation
-from pyinfra.facts.systemd import _make_systemctl_cmd, SystemdEnabled, SystemdStatus
+from pyinfra.facts.systemd import SystemdEnabled, SystemdStatus, _make_systemctl_cmd
 
 from .util.service import handle_service_control
 
 
 @operation(is_idempotent=False)
 def daemon_reload(user_mode=False, machine=None, user_name=None):
-    '''
+    """
     Reload the systemd daemon to read unit file changes.
 
     + user_mode: whether to use per-user systemd (systemctl --user) or not
     + machine: the machine name to connect to
     + user_name: connect to a specific user's systemd session
-    '''
+    """
 
     systemctl_cmd = _make_systemctl_cmd(
         user_mode=user_mode,
@@ -25,7 +25,7 @@ def daemon_reload(user_mode=False, machine=None, user_name=None):
         user_name=user_name,
     )
 
-    yield '{0} daemon-reload'.format(systemctl_cmd)
+    yield "{0} daemon-reload".format(systemctl_cmd)
 
 
 _daemon_reload = daemon_reload  # noqa: E305
@@ -34,11 +34,17 @@ _daemon_reload = daemon_reload  # noqa: E305
 @operation
 def service(
     service,
-    running=True, restarted=False, reloaded=False,
-    command=None, enabled=None, daemon_reload=False,
-    user_mode=False, machine=None, user_name=None,
+    running=True,
+    restarted=False,
+    reloaded=False,
+    command=None,
+    enabled=None,
+    daemon_reload=False,
+    user_mode=False,
+    machine=None,
+    user_name=None,
 ):
-    '''
+    """
     Manage the state of systemd managed units.
 
     + service: name of the systemd unit to manage
@@ -71,7 +77,7 @@ def service(
             enabled=True,
         )
 
-    '''
+    """
 
     systemctl_cmd = _make_systemctl_cmd(
         user_mode=user_mode,
@@ -79,8 +85,8 @@ def service(
         user_name=user_name,
     )
 
-    if '.' not in service:
-        service = '{0}.service'.format(service)
+    if "." not in service:
+        service = "{0}.service".format(service)
 
     if daemon_reload:
         yield from _daemon_reload(
@@ -91,13 +97,18 @@ def service(
 
     yield from handle_service_control(
         host,
-        service, host.get_fact(
+        service,
+        host.get_fact(
             SystemdStatus,
             user_mode=user_mode,
             machine=machine,
             user_name=user_name,
-        ), ' '.join([systemctl_cmd, '{1}', '{0}']),
-        running, restarted, reloaded, command,
+        ),
+        " ".join([systemctl_cmd, "{1}", "{0}"]),
+        running,
+        restarted,
+        reloaded,
+        command,
     )
 
     if isinstance(enabled, bool):
@@ -111,10 +122,10 @@ def service(
 
         # Isn't enabled and want enabled?
         if not is_enabled and enabled is True:
-            yield '{0} enable {1}'.format(systemctl_cmd, service)
+            yield "{0} enable {1}".format(systemctl_cmd, service)
             systemd_enabled[service] = True
 
         # Is enabled and want disabled?
         elif is_enabled and enabled is False:
-            yield '{0} disable {1}'.format(systemctl_cmd, service)
+            yield "{0} disable {1}".format(systemctl_cmd, service)
             systemd_enabled[service] = False
