@@ -23,13 +23,18 @@ def _has_package(package, packages, expand_package_fact=None, match_any=False):
 
 
 def ensure_packages(
-    host, packages, current_packages, present,
-    install_command, uninstall_command,
-    latest=False, upgrade_command=None,
+    host,
+    packages,
+    current_packages,
+    present,
+    install_command,
+    uninstall_command,
+    latest=False,
+    upgrade_command=None,
     version_join=None,
     expand_package_fact=None,
 ):
-    '''
+    """
     Handles this common scenario:
 
     + We have a list of packages(/versions) to ensure
@@ -48,7 +53,7 @@ def ensure_packages(
         upgrade_command (str): as above for upgrading
         version_join (str): the package manager specific "joiner", ie ``=`` for \
             ``<apt_pkg>=<version>``
-    '''
+    """
 
     if packages is None:
         return
@@ -60,17 +65,10 @@ def ensure_packages(
     # Version support?
     if version_join:
         # Split where versions present
-        packages = [
-            package.rsplit(version_join, 1)
-            for package in packages
-        ]
+        packages = [package.rsplit(version_join, 1) for package in packages]
 
         # Covert to either string or list
-        packages = [
-            package[0] if len(package) == 1
-            else package
-            for package in packages
-        ]
+        packages = [package[0] if len(package) == 1 else package for package in packages]
 
     # Diff the ensured packages against the remote state/fact
     diff_packages = []
@@ -93,11 +91,14 @@ def ensure_packages(
                 if not latest:
                     pkg_key = package[0] if isinstance(package, list) else package
                     if pkg_key in current_packages:
-                        host.noop('package {0} is installed ({1})'.format(
-                            package, ', '.join(current_packages[pkg_key]),
-                        ))
+                        host.noop(
+                            "package {0} is installed ({1})".format(
+                                package,
+                                ", ".join(current_packages[pkg_key]),
+                            ),
+                        )
                     else:
-                        host.noop('package {0} is installed'.format(package))
+                        host.noop("package {0} is installed".format(package))
 
     # Uninstalling?
     else:
@@ -107,26 +108,24 @@ def ensure_packages(
                 diff_packages.append(package)
 
             else:
-                host.noop('package {0} is not installed'.format(package))
+                host.noop("package {0} is not installed".format(package))
 
     # Convert packages back to string(/version)
     diff_packages = [
-        version_join.join(package)
-        if isinstance(package, list)
-        else package
+        version_join.join(package) if isinstance(package, list) else package
         for package in diff_packages
     ]
 
     if diff_packages:
         command = install_command if present else uninstall_command
 
-        yield '{0} {1}'.format(
+        yield "{0} {1}".format(
             command,
-            ' '.join([shlex.quote(pkg) for pkg in diff_packages]),
+            " ".join([shlex.quote(pkg) for pkg in diff_packages]),
         )
 
         for package in diff_packages:  # add/remove from current packages
-            version = 'unknown'
+            version = "unknown"
             if version_join:
                 bits = package.rsplit(version_join, 1)
                 package = bits[0]
@@ -139,9 +138,9 @@ def ensure_packages(
                 current_packages.pop(package, None)
 
     if latest and upgrade_command and upgrade_packages:
-        yield '{0} {1}'.format(
+        yield "{0} {1}".format(
             upgrade_command,
-            ' '.join([shlex.quote(pkg) for pkg in upgrade_packages]),
+            " ".join([shlex.quote(pkg) for pkg in upgrade_packages]),
         )
 
 
@@ -151,7 +150,7 @@ def ensure_rpm(state, host, files, source, present, package_manager_command):
     # If source is a url
     if urlparse(source).scheme:
         # Generate a temp filename (with .rpm extension to please yum)
-        temp_filename = '{0}.rpm'.format(state.get_temp_filename(source))
+        temp_filename = "{0}.rpm".format(state.get_temp_filename(source))
 
         # Ensure it's downloaded
         yield from files.download(source, temp_filename)
@@ -165,50 +164,60 @@ def ensure_rpm(state, host, files, source, present, package_manager_command):
 
     # We have info!
     if info:
-        current_package = host.get_fact(RpmPackage, name=info['name'])
-        if current_package and current_package['version'] == info['version']:
+        current_package = host.get_fact(RpmPackage, name=info["name"])
+        if current_package and current_package["version"] == info["version"]:
             exists = True
 
     # Package does not exist and we want?
     if present and not exists:
         # If we had info, always install
         if info:
-            yield 'rpm -i {0}'.format(source)
-            host.create_fact(RpmPackage, kwargs={'name': info['name']}, data=info)
+            yield "rpm -i {0}".format(source)
+            host.create_fact(RpmPackage, kwargs={"name": info["name"]}, data=info)
 
         # This happens if we download the package mid-deploy, so we have no info
         # but also don't know if it's installed. So check at runtime, otherwise
         # the install will fail.
         else:
-            yield 'rpm -q `rpm -qp {0}` 2> /dev/null || rpm -i {0}'.format(source)
+            yield "rpm -q `rpm -qp {0}` 2> /dev/null || rpm -i {0}".format(source)
 
     # Package exists but we don't want?
     elif exists and not present:
-        yield '{0} remove -y {1}'.format(package_manager_command, info['name'])
-        host.delete_fact(RpmPackage, kwargs={'name': info['name']})
+        yield "{0} remove -y {1}".format(package_manager_command, info["name"])
+        host.delete_fact(RpmPackage, kwargs={"name": info["name"]})
 
     else:
-        host.noop('rpm {0} is {1}'.format(
-            original_source,
-            'installed' if present else 'not installed',
-        ))
+        host.noop(
+            "rpm {0} is {1}".format(
+                original_source,
+                "installed" if present else "not installed",
+            ),
+        )
 
 
 def ensure_yum_repo(
-    state, host, files,
-    name_or_url, baseurl, present, description, enabled, gpgcheck, gpgkey,
-    repo_directory='/etc/yum.repos.d/',
+    state,
+    host,
+    files,
+    name_or_url,
+    baseurl,
+    present,
+    description,
+    enabled,
+    gpgcheck,
+    gpgkey,
+    repo_directory="/etc/yum.repos.d/",
     type_=None,
 ):
     url = None
     url_parts = urlparse(name_or_url)
     if url_parts.scheme:
         url = name_or_url
-        name_or_url = url_parts.path.split('/')[-1]
-        if name_or_url.endswith('.repo'):
+        name_or_url = url_parts.path.split("/")[-1]
+        if name_or_url.endswith(".repo"):
             name_or_url = name_or_url[:-5]
 
-    filename = '{0}{1}.repo'.format(repo_directory, name_or_url)
+    filename = "{0}{1}.repo".format(repo_directory, name_or_url)
 
     # If we don't want the repo, just remove any existing file
     if not present:
@@ -226,21 +235,21 @@ def ensure_yum_repo(
 
     # Build the repo file from string
     repo_lines = [
-        '[{0}]'.format(name_or_url),
-        'name={0}'.format(description),
-        'baseurl={0}'.format(baseurl),
-        'enabled={0}'.format(1 if enabled else 0),
-        'gpgcheck={0}'.format(1 if gpgcheck else 0),
+        "[{0}]".format(name_or_url),
+        "name={0}".format(description),
+        "baseurl={0}".format(baseurl),
+        "enabled={0}".format(1 if enabled else 0),
+        "gpgcheck={0}".format(1 if gpgcheck else 0),
     ]
 
     if type_:
-        repo_lines.append('type={0}'.format(type_))
+        repo_lines.append("type={0}".format(type_))
 
     if gpgkey:
-        repo_lines.append('gpgkey={0}'.format(gpgkey))
+        repo_lines.append("gpgkey={0}".format(gpgkey))
 
-    repo_lines.append('')
-    repo = '\n'.join(repo_lines)
+    repo_lines.append("")
+    repo = "\n".join(repo_lines)
     repo = StringIO(repo)
 
     # Ensure this is the file on the server
